/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

/**
 *
 * 金额转换，支持小数点，单位，千分位配置
 * @category  format
 * @param {number} m 输入金额
 * @param {Rule} [rule] interface接口，支持是否使用千分位，
 * @returns {(string|number)}
 * @author hzxiongxu
 * @date 20210520
 *
 */
function moneyFormat(m, rule) {
    // 默认2位小数加上千分位
    var p = {
        decimalPlaces: 2,
        useThousands: true,
        unit: '',
        symbol: ''
    };
    var params = __assign(__assign({}, p), rule);
    var result = '0.00';
    if (m !== null && m !== undefined) {
        var fixedNum = Number(m).toFixed(params.decimalPlaces);
        result = params.useThousands ? fixedNum.replace(/\B(?=(\d{3})+\b)/g, ',') : fixedNum;
    }
    return "" + params.symbol + result + params.unit;
}
/**
 * 格式化卡号格式：仅数字，4位一空格 （1111 2222 3333）
 * @format  format
 * @param {string} value
 * @param {number} limit
 * @author hzxiongxu
 * @date 20210520
 */
function cardNoFormat(value, limit) {
    if (limit === void 0) { limit = 25; }
    if (value) {
        var formatValue = value.replace(/[^0-9]/g, '');
        if (limit) {
            formatValue = formatValue.length > limit ? formatValue.slice(0, limit) : formatValue;
        }
        return formatValue.replace(/(\d{4})(?=.)/g, '$1 ');
    }
    return value;
}
/**
 *
 * 格式化手机号格式：仅数字，344分隔 （133 2222 3333）
 * @category format
 * @param {string} value
 * @returns {string}
 * @author hzxiongxu
 * @date 20210520
 *
 */
function mobileNoFormat(value) {
    if (value) {
        var formatValue = value.replace(/[^0-9]/g, '');
        return formatValue.replace(/(\d{3})(?!$)/, '$1 ').replace(/(\d{4})(?!$)/, '$1 ');
    }
    return value;
}

export { cardNoFormat, mobileNoFormat, moneyFormat };
